## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 4;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%bcond_without tests

%global forgeurl https://github.com/monocasual/giada

%global rtaudio_forgeurl https://github.com/monocasual/rtaudio
# Version for the bundled rtaudio fork
%global rtaudio_version 6.0.0~beta1
# Commit hash for the bundled rtaudio fork, included as a git submodule:
%global rtaudio_commit 885b71dfb6e3b66852ea987a6b10c2d305c505fd
%global rtaudio_shortcommit %(echo %{rtaudio_commit} | cut -b -8)

%global mas_forgeurl https://github.com/monocasual/mcl-atomic-swapper
# Commit hash for the bundled mcl-atomic-swapper, included as a git submodule:
%global mas_commit acc48c7ab416575f2fde1afd19faa0be378bb595
%global mas_shortcommit %(echo %{mas_commit} | cut -b -8)

%global mab_forgeurl https://github.com/monocasual/mcl-audio-buffer
# Commit hash for the bundled mcl-audio-buffer, included as a git submodule:
%global mab_commit d641e3e40219ea931e2a9945a1ef0aa2f54f4d2c
%global mab_shortcommit %(echo %{mab_commit} | cut -b -8)

Name:           giada
Version:        0.22.0
Release:        %autorelease
Summary:        Your hardcore loop machine

%global app_id com.giadamusic.Giada

# LICENSING NOTE:
#
# The upstream source, when downloaded from the main website (i.e.,
# %%{url}/data/giada-%%{version}-src.tar.gz), contains excerpts from the
# Steinberg VST 3 SDK, which has additional restrictions on top of the GPLv3
# that make it unsuitable for distribution in Fedora. See
# https://lists.fedoraproject.org/archives/list/legal@lists.fedoraproject.org/message/FMFIZU22AP36J3DOUVCXUPHQ3MNDN5P6/.
#
# These problematic components may be filtered from the upstream source archive
# using a script to produce a distributable source archive. At one point, this
# package followed that approach. Now we use the GitHub release tarball; since
# the problematic components (vst3sdk and juce) are git submodules, they are
# not included in the automatically-generated release tarball.
#
# Note that this means Giada will *not* be built with VST3 support in Fedora.
# (The situation for VST2 is even worse, as it is available only under a
# proprietary license.)
#
# Additional git submodules are handled as follows:
#   • json: unbundled downstream
#   • geompp: unbundled downstream
#   • rtaudio: bundled, provided as an additional source, since it is a
#     giada-specific fork
#   • mcl-atomic-swapper: bundled, provided as an additional source; this is
#     managed under the same GitHub organization as giada, and does not yet
#     have its own releases.
#   • mcl-audio-buffer: bundled, provided as an additional source; this is
#     managed under the same GitHub organization as giada, and does not yet
#     have its own releases. More importantly, it is not header-only but does
#     not yet have a build system configuration, so we really cannot package it
#     separately.

# The entire source is GPL-3.0-or-later, except:
#   - src/deps/rtaudio (i.e., the contents of Source1) is MIT, except:
#     * src/deps/rtaudio/include/soundcard.h is BSD-2-Clause
License:        GPL-3.0-or-later AND MIT AND BSD-2-Clause
URL:            https://www.giadamusic.com
Source0:        %{forgeurl}/archive/v%{version}/giada-%{version}.tar.gz
Source1:        %{rtaudio_forgeurl}/archive/%{rtaudio_commit}/rtaudio-%{rtaudio_shortcommit}.tar.gz
Source2:        %{mas_forgeurl}/archive/%{mas_commit}/mcl-atomic-swapper-%{mas_shortcommit}.tar.gz
Source3:        %{mab_forgeurl}/archive/%{mab_commit}/mcl-audio-buffer-%{mab_shortcommit}.tar.gz

# This is a C++ logging wrapper that passes its format string parameter through
# to std::fprintf, which inherently means the format string cannot be a
# literal. We use GCC pragmas to suppress the warning in just this one spot.
# See https://github.com/monocasual/giada/issues/447, where this is discussed,
# and the patch is offered, upstream.
Patch:          giada-0.17.2-suppress-format-security.patch
# Remove duplicate Comment in desktop file
# https://github.com/monocasual/giada/pull/589
Patch:          %{forgeurl}/pull/589.patch
# Support external nlohmann_json
# https://github.com/monocasual/giada/pull/590
Patch:          %{forgeurl}/pull/590.patch
# Downstream patch to use rtmidi 4.0, until the package is updated to 5.0,
# RHBZ#2023879. We just patch out the case for RtMidi::Api::WEB_MIDI_API,
# which is an rtmidi 5.0 feature, from a logging function.
#
# Once we can drop this patch, we should amend the BR to:
#   BuildRequires:  pkgconfig(rtmidi) >= 5.0.0
Patch:          0001-Patch-for-RtMidi-4.patch

BuildRequires:  desktop-file-utils
# For AppData file validation
# Still required by guidelines for now
# (https://pagure.io/packaging-committee/issue/1053):
BuildRequires:  libappstream-glib
# Matches what gnome-software and others use:
BuildRequires:  appstream

BuildRequires:  gcc-c++
BuildRequires:  cmake
# It is our choice whether to use the make backend or the ninja backend.
BuildRequires:  ninja-build

BuildRequires:  pkgconfig(rtmidi)

BuildRequires:  cmake(FLTK)
# CMakeLists.txt has:
#   set(FLTK_SKIP_FLUID TRUE)  # Don't search for FLTK's fluid
# but this doesn’t seem to be working. See also:
#   https://cmake.org/cmake/help/latest/module/FindFLTK.html
# The easiest workaround is just to ensure it is present:
BuildRequires:  fltk-fluid
# The static version of fltk appears to be required as well. However, this
# seems to be only a CMake config quirk, as we have verified (with ldd) that
# the giada executable links the libfltk.so[…] shared library.
BuildRequires:  fltk-static

BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  cmake(fmt)

BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)

BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(freetype2)

BuildRequires:  cmake(nlohmann_json)
BuildRequires:  json-static
BuildRequires:  geompp-devel
BuildRequires:  geompp-static

%if %{with tests}
BuildRequires:  cmake(Catch2)
# Support graphical tests in non-graphical environment
BuildRequires:  xorg-x11-server-Xvfb
%endif

# For /usr/share/icons/hicolor/*/apps
Requires:  hicolor-icon-theme

# ============================================================================
# RtAudio (https://github.com/thestk/rtaudio)
#
# This version is slightly forked, so it is not possible to build with the
# system copy of RtAudio. See
# https://giadamusic.com/forum/viewtopic.php?f=2&t=177, where upstream
# discusses the decision to maintain a forked copy of RtAudio in the Giada
# source tree.
#
# The version comes from “#define RTAUDIO_VERSION” in
# src/deps/rtaudio/RtAudio.h and/or AC_INIT in configure.ac.
Provides:  bundled(rtaudio) = %{rtaudio_version}
# ============================================================================

# ============================================================================
# mcl-audio-buffer (https://github.com/monocasual/mcl-audio-buffer/)
#
# Currently, this is effectively still a part of giada. It has never had a
# version or a release, and it has no build system of its own. Since it is not
# header-only (compare to geompp), this makes it impractical to package it as a
# stand-alone library. Therefore we must bundle it as a part of giada until and
# unless it grows into a full-fledged project of its own.
Provides:  bundled(mcl-audio-buffer)
# ============================================================================

%description
Giada is an open source, minimalistic and hardcore music production tool.
Designed for DJs, live performers and electronic musicians.


%prep
%autosetup -p1

%setup -q -T -D -b 1 -n giada-%{version}
rm -rvf src/deps/rtaudio
cp -rp ../rtaudio-%{rtaudio_commit} src/deps/rtaudio
cp -p src/deps/rtaudio/LICENSE LICENSE-rtaudio

%setup -q -T -D -b 2 -n giada-%{version}
rm -rvf src/deps/mcl-atomic-swapper
cp -rp ../mcl-atomic-swapper-%{mas_commit} src/deps/mcl-atomic-swapper
cp -p src/deps/mcl-atomic-swapper/LICENSE LICENSE-mcl-atomic-swapper

%setup -q -T -D -b 3 -n giada-%{version}
rm -rvf src/deps/mcl-audio-buffer
cp -rp ../mcl-audio-buffer-%{mab_commit} src/deps/mcl-audio-buffer
cp -p src/deps/mcl-audio-buffer/LICENSE LICENSE-mcl-audio-buffer

# This is a last safeguard against something with an inappropriate license
# slipping into the source tarball. It is no substitute for manual auditing.
echo 'Checking for inappropriate source files:'
echo '> Possible Steinberg proprietary license?'
if grep -Frl 'This Software Development Kit may not be' .
then
  echo 'Found some concerning files!'
  exit 1
else
  echo '> No concerning files were found.'
fi
echo '> Possible Steinberg VST 3 SDK (GPLv3 with conditions)?'
if grep -Erli 'Project[[:blank:]]*:[[:blank:]]*VST SDK' .
then
  echo 'Found some concerning files!'
  exit 1
else
  echo '> No concerning files were found.'
fi

# Link fltk as a shared library:
sed -r -i 's/\b(fltk.*)\b/\1_SHARED/g' CMakeLists.txt

# Unbundle geompp; we can just use a symlink since it is a header-only library.
rm -rvf 'src/deps/geompp'
mkdir 'src/deps/geompp'
ln -s '%{_includedir}/geompp' 'src/deps/geompp/src'


%build
# Make sure any build flags for unbundled libraries are set. For
# json/nlohmann_json, we expect that none are needed in practice.
%set_build_flags
export CFLAGS="${CFLAGS} $(pkgconf --cflags nlohmann_json)"
export CXXFLAGS="${CXXFLAGS} $(pkgconf --cflags nlohmann_json)"
export LDFLAGS="${CXXFLAGS} $(pkgconf --libs nlohmann_json)"

# VST 2 SDK is only available under a proprietary license, and VST 3 SDK is
# dual-licensed with a proprietary license and GPLv3, but additional
# trademark-related conditions are imposed that are not acceptable in Fedora.
# See the notes near the beginning of this spec file. Therefore the VST 3 SDK
# and JUCE sources have been excluded, and all VST support must be disabled at
# build time.
%cmake \
    -DWITH_VST2:BOOL=OFF -DWITH_VST3:BOOL=OFF \
    -DWITH_TESTS:BOOL=%{?with_tests:ON}%{?!with_tests:OFF} \
    -DWITH_SYSTEM_JSON:BOOL=ON \
    -GNinja
%cmake_build


%install 
%cmake_install


%check
# Verify the bundled rtaudio version in the spec file matches the header in the
# source tree.
[ '"%(echo '%{rtaudio_version}' | tr -d '~')"' = "$(
  awk '$1 == "#define" && $2 == "RTAUDIO_VERSION" { print $3; exit }' \
      src/deps/rtaudio/RtAudio.h)" ]
# This comment fixes broken vim syntax highlighting --> "

# Validate the installed desktop file as required by
# https://docs.fedoraproject.org/en-US/packaging-guidelines/#_desktop_file_install_usage.
desktop-file-validate %{buildroot}%{_datadir}/applications/%{app_id}.desktop

# Validate the installed AppData file. Fedora guidelines require validate-relax
# to pass (but not validate-strict), and do require validation at build time.
#
# Still required by guidelines for now
# (https://pagure.io/packaging-committee/issue/1053):
appstream-util validate-relax --nonet \
    %{buildroot}%{_metainfodir}/%{app_id}.metainfo.xml
# Matches what gnome-software and others use:
appstreamcli validate --nonet \
    %{buildroot}%{_metainfodir}/%{app_id}.metainfo.xml

%if %{with tests}
xvfb-run -a %{buildroot}%{_bindir}/giada --run-tests
%endif


%files
%license COPYING LICENSE-rtaudio LICENSE-mcl-audio-buffer
%doc ChangeLog README.md

%{_bindir}/giada

%{_metainfodir}/%{app_id}.metainfo.xml
%{_datadir}/applications/%{app_id}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{app_id}.svg


%changelog
* Thu Aug 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.22.0-4
- Update License to SPDX

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> 0.22.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.22.0-2
- Rebuilt for fmt 9.0.0

* Sun Jun 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.22.0-1
- Update to 0.22.0 (close RHBZ#2096032)

* Sat Apr 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.21.0-2
- Stop numbering patches

* Tue Mar 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.21.0-1
- Update to 0.21.0 (close RHBZ#2069093)

* Sat Feb 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.20.1-1
- Update to 0.20.1 (close RHBZ#2056265); drop “forge” macros

* Tue Feb 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.20.0-2
- Finish updating to 0.20.0 (missing changes from previous commit)

* Tue Feb 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.20.0-1
- Update to 0.20.0 (fix RHBZ#2045433, fix RHBZ#2045433)

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> 0.19.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.19.2-2
- Also validate AppData with appstreamcli

* Fri Dec 17 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.19.2-1
- Update to 0.19.2 (close RHBZ#2033508)

* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.19.1-1
- Update to 0.19.1 (close RHBZ#2033127)

* Tue Nov 02 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.19.0-1
- Update to 0.19.0 (close RHBZ#2019261)

* Wed Oct 06 2021 Kevin Fenzi <kevin@scrye.com> 0.18.2-2
- rebuild for new rtmidi in sidetag

* Sun Sep 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.18.2-1
- Update to 0.18.2 (close RHBZ#2003464)

* Sun Jul 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.18.1-1
- Update to 0.18.1 (closes RHBZ#1985694)

* Sun Jul 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.18.0.1-5
- Improve licensing note regarding git submodules and bundling

* Sun Jul 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> 0.18.0.1-4
- Add license file from bundled rtaudio fork

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> 0.18.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue May 18 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.18.0.1-1
- Update to 0.18.0.1
- Unbundle new geompp header-only library dependency
- Drop giada-0.17.2-missing-include-string.patch since
  https://github.com/monocasual/giada/issues/454 was fixed

* Wed May 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-6
- Move “forge” macros to the top of the spec file

* Mon Apr 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-5
- Drop one more accommodation for Fedora 32

* Sat Apr 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-4
- Drop workarounds for Fedora 32

* Sat Apr 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-3.1
- Another Fedora 32 fix to prevent FTBFS in Koschei

* Mon Mar 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-3
- Typo fix

* Mon Mar 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-2
- Drop json-static workaround in Fedora 35+

* Sun Mar 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.2-1
- New upstream version 0.17.2
- Replace giada-0.17.1-fix-install-path.patch with setting CMAKE_INSTALL_PREFIX
  to an unusual value
- Switch to GitHub source tarball
- Validate bundled rtaudio version in %%check
- Work around arched json-static for now

* Sat Mar 27 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-5.1
- Fix Fedora 32 compatibility

* Fri Mar 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-5
- Unbundle json/“JSON for Modern C++”/nlohmann_json

* Fri Feb 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-4.1
- Add Fedora 32 compatibility

* Thu Feb 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-4
- Remove VST 3 SDK and JUCE from source tarball for legal reasons; disable all
  VST support
- Update License field to reflect the removed bundled dependencies
- Remove stray debugging “find” commands

* Tue Feb 23 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-3
- Add link to upstream issue for format-security patch
- Add commentary on forked bundled rtaudio, with a link to upstream discussion

* Tue Feb 23 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-2
- Disable VST3 on PPC64LE due to a non-obvious linker error

* Mon Feb 22 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.17.1-2
- New upstream release 0.17.1
- Switch to CMake build system
- Add AppData and updated desktop file from
  https://github.com/monocasual/giada/pull/358
- Add virtual Provides, and update License field, for bundled dependencies
- Update summary and description from upstream
- Build Giada with tests, and run them at build time

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.17.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Nov 24 2020 Erich Eickmeyer <erich@ericheickmeyer.com> - 0.17.0-1
- New upstream release
- Add CMake build system
- VST3 support
- Show descriptive plug-in names in Plug-in List Window
- Resizable plug-in list
- New persistence mechanism for Plug-ins state
- Improved text truncation for small buttons and text boxes
- Beautify Sample Editor window
- Resizable plug-in list window
- Show descriptive plug-in name in plug-in list
- Update JUCE, version 6.0.4
- Update Catch2 to version 2.13.2
- Replace old filesystem functions in fs.h with std::filesystem
- Add VST3 SDK as git submodule
- Set minimum macOS version to 10.14
- Statically link the MSVC runtime library on Windows
- Avoid crash on opening plug-in list with invalid plug-ins
- Rewind sample channels in loop.once.bar mode on bar, if still playing (fix #403)
- Modernize log::print() function to handle std::string arguments (PR #402)
- Fix playStatus logic for ending sample channels in loop-once-bar mode (#404)
- Fix shrinking beats that could glitch the output (#361)

* Thu Oct 08 2020 Erich Eickmeyer <erich@ericheickmeyer.com> - 0.16.4-1
- New upstream release
- Support for mono inputs
- Overdub mode for Sample Channels with optional overdub protection
- Disable record-on-signal mode when sequencer is running
- Shift + [click on R button] kills action reading when "Treat one-shot
  channels with actions as loops" option is on
- Start MIDI channels automatically after action recording session
- Fix wrong sample rate conversion when project rate != system rate
- Fix Wrong begin/end sample markers when loading a project with samplerate != 
  system.samplerate
- Fix wrong MIDI learn mapping for master parameters
- Fix BPM button disabled after audio recording session

* Fri Aug 07 2020 Erich Eickmeyer <erich@ericheickmeyer.com> - 0.16.3.1-1
- New upstream release
- Resolves: rhbz #1863622

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.3-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jun 15 2020 Erich Eickmeyer <erich@ericheickmeyer.com> - 0.16.3-1
- New upstream version

* Thu Mar 26 2020 Erich Eickmeyer <erich@ericheickmeyer.com> - 0.16.2.2-1
- New upstream version

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Wed Jul 10 2019 Filipe Rosset <rosset.filipe@gmail.com> - 0.15.4-1
- Update to 0.15.4 fixes rhbz#1604101 rhbz#1674963 and rhbz#1703719

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Jan 07 2018 Orcan Ogetbil <oget[dot]fedora[at]gmail[dot] com> - 0.14.4-1
- Update to 0.14.4

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.7.0-8
- Rebuilt for GCC 5 C++11 ABI change

* Thu Feb 19 2015 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-7
- Fix FTBFS (gcc5?), don't build with -Werror

* Thu Feb 19 2015 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-6
- rebuild (fltk)

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jun 12 2013 Brendan Jones <brendan.jones.it@gmail.com> 0.7.0-2
- Add missing libsamplerate

* Wed Jun 12 2013 Brendan Jones <brendan.jones.it@gmail.com> 0.7.0-1
- New upstream 0.7.0

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 10 2013 Brendan Jones <brendan.jones.it@gmail.com> 0.5.6-1
- New upstream release

* Tue Dec 11 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.4-2
- Rebuild for new rtaudio

* Thu Nov 29 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.4-1
- New upstream, removing vst patch
- Apply desktop translation patch from Ismael Olea
- Remove unecessary scriptlets and add a more descriptive summary

* Mon Nov 26 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.2-4
- Missing BR libXext-devel

* Sun Nov 25 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.2-3
- Add missing BR rtaudio

* Sun Oct 21 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.2-2
- correct description and URL, add make flags

* Sun Oct 14 2012 Brendan Jones <brendan.jones.it@gmail.com> 0.5.2-1
- Initial package

